==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/he-IL/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'אודות מיקומים',
    'about_locations'           => 'מיקומים משמשים למעקב אחר נתוני מיקום עבור משתמשים, נכסים ופריטים אחרים',
    'assets_rtd'                => 'נכסים', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'הנכסים הוקצו',
    'id'                        => 'תְעוּדַת זֶהוּת',
    'city'                      => 'עִיר',
    'state'                     => 'מדינה',
    'country'                   => 'מדינה',
    'create'                    => 'צור מיקום',
    'update'                    => 'עדכן מיקום',
    'print_assigned'            => 'להדפיס הקצאה',
    'print_all_assigned'        => 'להדפיס את כל ההקצאות',
    'name'                      => 'שם מיקום',
    'address'                   => 'כתובת',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'מיקוד',
    'locations'                 => 'מיקומים',
    'parent'                    => 'הוֹרֶה',
    'currency'                  => 'מטבע מיקום',
    'ldap_ou'                   => 'חיפוש OD של LDAP',
    'user_name'                 => 'שם משתמש',
    'department'                => 'מחלקה',
    'location'                  => 'מיקום',
    'asset_tag'                 => 'Assets Tag',
    'asset_name'                => 'שם',
    'asset_category'            => 'קטגוריה',
    'asset_manufacturer'        => 'יצרן',
    'asset_model'               => 'דגם',
    'asset_serial'              => 'מס׳ סידורי',
    'asset_location'            => 'מיקום',
    'asset_checked_out'         => 'הנכס שוייך',
    'asset_expected_checkin'    => 'תאריך חזרה למלאי',
    'date'                      => 'תאריך:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'אושר על ידי (מפקח הציוד):',
    'signed_by_finance_auditor' => 'אושר על ידי (מפקח הכספים):',
    'signed_by_location_manager' => 'אושר על ידי (מנהל המיקום):',
    'signed_by'                 => 'אושר על ידי:',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/he-IL/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'אודות מיקומים',
    'about_locations'           => 'מיקומים משמשים למעקב אחר נתוני מיקום עבור משתמשים, נכסים ופריטים אחרים',
    'assets_rtd'                => 'נכסים', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'הנכסים הוקצו',
    'id'                        => 'תְעוּדַת זֶהוּת',
    'city'                      => 'עִיר',
    'state'                     => 'מדינה',
    'country'                   => 'מדינה',
    'create'                    => 'צור מיקום',
    'update'                    => 'עדכן מיקום',
    'print_assigned'            => 'להדפיס הקצאה',
    'print_all_assigned'        => 'להדפיס את כל ההקצאות',
    'name'                      => 'שם מיקום',
    'address'                   => 'כתובת',
    'address2'                   => 'שורת כתובת 2',
    'zip'                       => 'מיקוד',
    'locations'                 => 'מיקומים',
    'parent'                    => 'הוֹרֶה',
    'currency'                  => 'מטבע מיקום',
    'ldap_ou'                   => 'חיפוש OD של LDAP',
    'user_name'                 => 'שם משתמש',
    'department'                => 'מחלקה',
    'location'                  => 'מיקום',
    'asset_tag'                 => 'תגית פריטים',
    'asset_name'                => 'שם',
    'asset_category'            => 'קטגוריה',
    'asset_manufacturer'        => 'יצרן',
    'asset_model'               => 'דגם',
    'asset_serial'              => 'מס׳ סידורי',
    'asset_location'            => 'מיקום',
    'asset_checked_out'         => 'הנכס שוייך',
    'asset_expected_checkin'    => 'תאריך חזרה למלאי',
    'date'                      => 'תאריך:',
    'phone'                     => 'מיקום טלפון',
    'signed_by_asset_auditor'   => 'אושר על ידי (מפקח הציוד):',
    'signed_by_finance_auditor' => 'אושר על ידי (מפקח הכספים):',
    'signed_by_location_manager' => 'אושר על ידי (מנהל המיקום):',
    'signed_by'                 => 'אושר על ידי:',
];
